@@ -66,6 +66,7 @@ class AzureAIInferenceChatCompletion(ChatCompletionClientBase, AzureAIInferenceB
         ai_model_id: str,
         api_key: str | None = None,
         endpoint: str | None = None,
+        api_version: str | None = None,
         service_id: str | None = None,
         env_file_path: str | None = None,
         env_file_encoding: str | None = None,
@@ -78,11 +79,13 @@ class AzureAIInferenceChatCompletion(ChatCompletionClientBase, AzureAIInferenceB
         The following environment variables are used:
         - AZURE_AI_INFERENCE_API_KEY
         - AZURE_AI_INFERENCE_ENDPOINT
+        - AZURE_AI_INFERENCE_API_VERSION
 
         Args:
             ai_model_id: (str): A string that is used to identify the model such as the model name. (Required)
             api_key (str | None): The API key for the Azure AI Inference service deployment. (Optional)
             endpoint (str | None): The endpoint of the Azure AI Inference service deployment. (Optional)
+            api_version (str | None): The API version to use. (Optional)
             service_id (str | None): Service ID for the chat completion service. (Optional)
             env_file_path (str | None): The path to the environment file. (Optional)
             env_file_encoding (str | None): The encoding of the environment file. (Optional)
@@ -99,6 +102,7 @@ class AzureAIInferenceChatCompletion(ChatCompletionClientBase, AzureAIInferenceB
             "client_type": AzureAIInferenceClientType.ChatCompletions,
             "client": client,
             "endpoint": endpoint,
+            "api_version": api_version,
             "env_file_path": env_file_path,
             "env_file_encoding": env_file_encoding,
         }
@@ -139,6 +143,9 @@ class AzureAIInferenceChatCompletion(ChatCompletionClientBase, AzureAIInferenceB
         assert isinstance(self.client, ChatCompletionsClient)  # nosec
         with AzureAIInferenceTracing():
             settings_dict = settings.prepare_settings_dict()
+            # Remove the extra parameters since it will be passed in via the `model_extras` param
+            settings_dict.pop("extra_parameters", None)
+
             self._handle_structured_output(settings, settings_dict)
             response: ChatCompletions = await self.client.complete(
                 messages=self._prepare_chat_history_for_request(chat_history),
@@ -165,6 +172,9 @@ class AzureAIInferenceChatCompletion(ChatCompletionClientBase, AzureAIInferenceB
         assert isinstance(self.client, ChatCompletionsClient)  # nosec
         with AzureAIInferenceTracing():
             settings_dict = settings.prepare_settings_dict()
+            # Remove the extra parameters since it will be passed in via the `model_extras` param
+            settings_dict.pop("extra_parameters", None)
+
             self._handle_structured_output(settings, settings_dict)
             response: AsyncStreamingChatCompletions = await self.client.complete(
                 stream=True,
