@@ -7,6 +7,7 @@ from copy import deepcopy
 from typing import Any, TypeVar
 from uuid import uuid4
 
+from azure.core.credentials import TokenCredential
 from openai import AsyncAzureOpenAI
 from openai.lib.azure import AsyncAzureADTokenProvider
 from openai.types.chat.chat_completion import ChatCompletion, Choice
@@ -55,6 +56,7 @@ class AzureChatCompletion(AzureOpenAIConfigBase, OpenAIChatCompletionBase, OpenA
         env_file_path: str | None = None,
         env_file_encoding: str | None = None,
         instruction_role: str | None = None,
+        credential: TokenCredential | None = None,
     ) -> None:
         """Initialize an AzureChatCompletion service.
 
@@ -80,6 +82,7 @@ class AzureChatCompletion(AzureOpenAIConfigBase, OpenAIChatCompletionBase, OpenA
             env_file_encoding (str | None): The encoding of the environment settings file, defaults to 'utf-8'.
             instruction_role (str | None): The role to use for 'instruction' messages, for example, summarization
                 prompts could use `developer` or `system`. (Optional)
+            credential (TokenCredential): The credential to use for authentication.
         """
         try:
             azure_openai_settings = AzureOpenAISettings(
@@ -112,6 +115,7 @@ class AzureChatCompletion(AzureOpenAIConfigBase, OpenAIChatCompletionBase, OpenA
             ai_model_type=OpenAIModelTypes.CHAT,
             client=async_client,
             instruction_role=instruction_role,
+            credential=credential,
         )
 
     @classmethod
