@@ -36,15 +36,14 @@ class HttpPlugin(KernelBaseModel):
         if not url:
             raise FunctionExecutionException("url cannot be `None` or empty")
 
-        async with aiohttp.ClientSession() as session:
-            async with session.get(url, raise_for_status=True) as response:
-                return await response.text()
+        async with aiohttp.ClientSession() as session, session.get(url, raise_for_status=True) as response:
+            return await response.text()
 
     @kernel_function(description="Makes a POST request to a uri", name="postAsync")
     async def post(
         self,
         url: Annotated[str, "The URI to send the request to."],
-        body: Annotated[dict[str, Any] | None, "The body of the request"] = {},
+        body: Annotated[dict[str, Any] | None, "The body of the request"] = None,
     ) -> str:
         """Sends an HTTP POST request to the specified URI and returns the response body as a string.
 
@@ -58,16 +57,18 @@ class HttpPlugin(KernelBaseModel):
             raise FunctionExecutionException("url cannot be `None` or empty")
 
         headers = {"Content-Type": "application/json"}
-        data = json.dumps(body)
-        async with aiohttp.ClientSession() as session:
-            async with session.post(url, headers=headers, data=data, raise_for_status=True) as response:
-                return await response.text()
+        data = json.dumps(body) if body is not None else None
+        async with (
+            aiohttp.ClientSession() as session,
+            session.post(url, headers=headers, data=data, raise_for_status=True) as response,
+        ):
+            return await response.text()
 
     @kernel_function(description="Makes a PUT request to a uri", name="putAsync")
     async def put(
         self,
         url: Annotated[str, "The URI to send the request to."],
-        body: Annotated[dict[str, Any] | None, "The body of the request"] = {},
+        body: Annotated[dict[str, Any] | None, "The body of the request"] = None,
     ) -> str:
         """Sends an HTTP PUT request to the specified URI and returns the response body as a string.
 
@@ -82,10 +83,12 @@ class HttpPlugin(KernelBaseModel):
             raise FunctionExecutionException("url cannot be `None` or empty")
 
         headers = {"Content-Type": "application/json"}
-        data = json.dumps(body)
-        async with aiohttp.ClientSession() as session:
-            async with session.put(url, headers=headers, data=data, raise_for_status=True) as response:
-                return await response.text()
+        data = json.dumps(body) if body is not None else None
+        async with (
+            aiohttp.ClientSession() as session,
+            session.put(url, headers=headers, data=data, raise_for_status=True) as response,
+        ):
+            return await response.text()
 
     @kernel_function(description="Makes a DELETE request to a uri", name="deleteAsync")
     async def delete(self, url: Annotated[str, "The URI to send the request to."]) -> str:
@@ -99,6 +102,5 @@ class HttpPlugin(KernelBaseModel):
         """
         if not url:
             raise FunctionExecutionException("url cannot be `None` or empty")
-        async with aiohttp.ClientSession() as session:
-            async with session.delete(url, raise_for_status=True) as response:
-                return await response.text()
+        async with aiohttp.ClientSession() as session, session.delete(url, raise_for_status=True) as response:
+            return await response.text()
