@@ -10,3 +10,6 @@ OPERATION = "gen_ai.operation.name"
 AGENT_ID = "gen_ai.agent.id"
 AGENT_NAME = "gen_ai.agent.name"
 AGENT_DESCRIPTION = "gen_ai.agent.description"
+AGENT_INVOCATION_INPUT = "gen_ai.agent.invocation_input"
+AGENT_INVOCATION_OUTPUT = "gen_ai.agent.invocation_output"
+ERROR_TYPE = "error.type"
